@@ -38,10 +38,26 @@ def get_pex_info(entry_point):
 
   pex_info_content = read_pex_info_content(entry_point)
   if pex_info_content:
-    return pex_info.PexInfo(pex_info_content)
+    return pex_info.PexInfo.from_json(pex_info_content)
   raise ValueError('Invalid entry_point: %s' % entry_point)
 
 
+# TODO(wickman) Remove once resolved:
+#   https://bitbucket.org/pypa/setuptools/issue/154/build_zipmanifest-results-should-be
+def monkeypatch_build_zipmanifest():
+  import pkg_resources
+  if not hasattr(pkg_resources, 'build_zipmanifest'):
+    return
+  old_build_zipmanifest = pkg_resources.build_zipmanifest
+  def memoized_build_zipmanifest(archive, memo={}):
+    if archive not in memo:
+      memo[archive] = old_build_zipmanifest(archive)
+    return memo[archive]
+  pkg_resources.build_zipmanifest = memoized_build_zipmanifest
+
+
 def bootstrap_pex(entry_point):
+  monkeypatch_build_zipmanifest()
+
   from . import pex
   pex.PEX(entry_point).execute()
